macro_rules! c_confirm_callback { ( $fn_name:ident, $type:ty, $safe_fn_name:ident ) => { ... }; }
Create a C-compatible callback to determine user confirmation which wraps safe Rust code
macro_rules! c_confirm_callback { ( $fn_name:ident, $type:ty, $safe_fn_name:ident ) => { ... }; }
Create a C-compatible callback to determine user confirmation which wraps safe Rust code