Struct libcryptsetup_rs::CryptParamsIntegrity
source · pub struct CryptParamsIntegrity {Show 13 fields
pub journal_size: u64,
pub journal_watermark: c_uint,
pub journal_commit_time: c_uint,
pub interleave_sectors: u32,
pub tag_size: u32,
pub sector_size: u32,
pub buffer_sectors: u32,
pub integrity: String,
pub integrity_key_size: u32,
pub journal_integrity: String,
pub journal_integrity_key: Vec<u8>,
pub journal_crypt: String,
pub journal_crypt_key: Vec<u8>,
}Expand description
Parameters for integrity checking
Fields
journal_size: u64journal_watermark: c_uintjournal_commit_time: c_uintinterleave_sectors: u32tag_size: u32sector_size: u32buffer_sectors: u32integrity: Stringintegrity_key_size: u32journal_integrity: Stringjournal_integrity_key: Vec<u8>journal_crypt: Stringjournal_crypt_key: Vec<u8>Trait Implementations
sourceimpl<'a> TryFrom<&'a crypt_params_integrity> for CryptParamsIntegrity
impl<'a> TryFrom<&'a crypt_params_integrity> for CryptParamsIntegrity
type Error = LibcryptErr
type Error = LibcryptErr
The type returned in the event of a conversion error.
sourceimpl<'a> TryInto<CryptParamsIntegrityRef<'a>> for &'a CryptParamsIntegrity
impl<'a> TryInto<CryptParamsIntegrityRef<'a>> for &'a CryptParamsIntegrity
type Error = LibcryptErr
type Error = LibcryptErr
The type returned in the event of a conversion error.