Struct libcryptsetup_rs::CryptParamsLoopaes
source · pub struct CryptParamsLoopaes {
pub hash: String,
pub offset: u64,
pub skip: u64,
}Expand description
Parameters for formatting a loop AES device
Fields
hash: Stringoffset: u64skip: u64Trait Implementations
sourceimpl<'a> TryFrom<&'a crypt_params_loopaes> for CryptParamsLoopaes
impl<'a> TryFrom<&'a crypt_params_loopaes> for CryptParamsLoopaes
type Error = LibcryptErr
type Error = LibcryptErr
The type returned in the event of a conversion error.
sourceimpl<'a> TryInto<CryptParamsLoopaesRef<'a>> for &'a CryptParamsLoopaes
impl<'a> TryInto<CryptParamsLoopaesRef<'a>> for &'a CryptParamsLoopaes
type Error = LibcryptErr
type Error = LibcryptErr
The type returned in the event of a conversion error.