Struct libcryptsetup_rs::CryptParamsVerity
source · pub struct CryptParamsVerity {Show 13 fields
pub hash_name: String,
pub data_device: PathBuf,
pub hash_device: PathBuf,
pub fec_device: PathBuf,
pub salt: Vec<u8>,
pub hash_type: u32,
pub data_block_size: u32,
pub hash_block_size: u32,
pub data_size: u64,
pub hash_area_offset: u64,
pub fec_area_offset: u64,
pub fec_roots: u32,
pub flags: CryptVerity,
}Expand description
Parameters specific to Verity
Fields
hash_name: Stringdata_device: PathBufhash_device: PathBuffec_device: PathBufsalt: Vec<u8>hash_type: u32data_block_size: u32hash_block_size: u32data_size: u64hash_area_offset: u64fec_area_offset: u64fec_roots: u32flags: CryptVerityTrait Implementations
sourceimpl<'a> TryFrom<&'a crypt_params_verity> for CryptParamsVerity
impl<'a> TryFrom<&'a crypt_params_verity> for CryptParamsVerity
type Error = LibcryptErr
type Error = LibcryptErr
The type returned in the event of a conversion error.
sourceimpl<'a> TryInto<CryptParamsVerityRef<'a>> for &'a CryptParamsVerity
impl<'a> TryInto<CryptParamsVerityRef<'a>> for &'a CryptParamsVerity
type Error = LibcryptErr
type Error = LibcryptErr
The type returned in the event of a conversion error.