pub struct CryptVolumeKeyHandle<'a> { /* private fields */ }
Handle for volume key operations
Get volume key from crypt device - first tuple element is key slot, second is volume key
size
Verify that volume key is valid for crypt device
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.