Macro libcryptsetup_rs::c_confirm_callback [−][src]
Create a C-compatible callback to determine user confirmation which wraps safe Rust code
Create a C-compatible callback to determine user confirmation which wraps safe Rust code